@@ -4,17 +4,17 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef AKONADI_SPECIALCOLLECTIONATTRIBUTE_P_H
-#define AKONADI_SPECIALCOLLECTIONATTRIBUTE_P_H
+#pragma once
 
 #include "akonadicore_export.h"
 #include "attribute.h"
 
 #include <QByteArray>
 
+#include <memory>
+
 namespace Akonadi
 {
-
 /**
  * @short An Attribute that stores the special collection type of a collection.
  *
@@ -53,12 +53,11 @@ public:
     void deserialize(const QByteArray &data) override;
 
 private:
-    //@cond PRIVATE
+    /// @cond PRIVATE
     class Private;
-    Private *const d;
-    //@endcond
+    const std::unique_ptr<Private> d;
+    /// @endcond
 };
 
 } // namespace Akonadi
 
-#endif // AKONADI_SPECIALCOLLECTIONATTRIBUTE_H
